<?php

namespace Drupal\gbif2_views\EventSubscriber;

use Drupal\gbif2_views\Service\GbifVboViewsData;
use Drupal\views_bulk_operations\ViewsBulkOperationsEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Integration with the Views Bulk Operations module.
 *
 * @see https://www.drupal.org/docs/8/modules/views-bulk-operations-vbo/view-providers-api
 */
class GbifVboEventSubscriber implements EventSubscriberInterface {

  /**
   * Object that gets the current view data.
   *
   * @var \Drupal\gbif2_views\Service\GbifVboViewsData
   */
  protected $viewData;

  /**
   * Object constructor.
   *
   * @param \Drupal\gbif2_views\Service\GbifVboViewsData $view_data
   *   The custom view data provider service.
   */
  public function __construct(GbifVboViewsData $view_data) {
    $this->viewData = $view_data;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events = [];

    // The next line prevents hard dependency on VBO module.
    if (class_exists(ViewsBulkOperationsEvent::class)) {
      $events['views_bulk_operations.view_data'][] = ['provideViewData', 0];
    }

    return $events;
  }

  /**
   * Provide "entity type data" and "entity getter" to VBO.
   *
   * @param \Drupal\views_bulk_operations\ViewsBulkOperationsEvent $event
   *   The event object.
   */
  public function provideViewData(ViewsBulkOperationsEvent $event) {
    if ($event->getProvider() === 'gbif2_views') {
      $event->setEntityTypeIds(['gbif_occurrence']);
      $event->setEntityGetter([
        'callable' => [$this->viewData, 'getEntityFromRow'],
      ]);
    }
  }

}
