<?php

namespace Drupal\gbif2_views\Plugin\views\field;

use Drupal\gbif2\Service\Helper;
use Drupal\views\Plugin\views\field\Standard;
use Drupal\views\ResultRow;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Handler for GBIF "basis of record" field.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("gbif_basis_of_record")
 */
class GbifBasisOfRecord extends Standard {

  /**
   * GBIF helper service.
   *
   * @var \Drupal\gbif2\Service\Helper
   */
  protected $gbifHelper;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, Helper $gbif_helper) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->gbifHelper = $gbif_helper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('gbif.helper')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $value = $this->getValue($values);
    $basis_of_record_values = $this->gbifHelper->basisOfRecordValues();
    if (isset($basis_of_record_values[$value])) {
      return [
        '#type' => 'html_tag',
        '#tag' => 'span',
        '#attributes' => [
          'title' => $basis_of_record_values[$value]['description'],
        ],
        '#value' => $basis_of_record_values[$value]['name'],
      ];
    }
  }

}
