<?php

namespace Drupal\gbif2_views\Plugin\views\field;

use Drupal\gbif2\Service\Helper;
use Drupal\views\Plugin\views\field\Standard;
use Drupal\views\ResultRow;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Handler for GBIF "basis of record" field.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("gbif_continent")
 */
class GbifContinent extends Standard {

  /**
   * GBIF helper service.
   *
   * @var \Drupal\gbif2\Service\Helper
   */
  protected $gbifHelper;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, Helper $gbif_helper) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->gbifHelper = $gbif_helper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('gbif.helper')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $value = $this->getValue($values);
    $continent_values = $this->gbifHelper->continentValues();
    if (isset($continent_values[$value])) {
      return ['#markup' => $continent_values[$value]];
    }
  }

}
