<?php

namespace Drupal\gbif2_views\Plugin\views\filter;

use Drupal\gbif2\Service\Helper;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Basis of record filter handler for GBIF.
 *
 * @ingroup views_filter_handlers
 *
 * @ViewsFilter("gbif_basis_of_record")
 */
class GbifBasisOfRecordFilter extends GbifInOperator {

  /**
   * GBIF helper service.
   *
   * @var \Drupal\gbif2\Service\Helper
   */
  protected $gbifHelper;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, Helper $gbif_helper) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->gbifHelper = $gbif_helper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('gbif.helper')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getValueOptions() {
    $options = [];

    foreach ($this->gbifHelper->basisOfRecordValues() as $machine_name => $option_values) {
      $options[$machine_name] = $option_values['name'];
    }
    $this->valueOptions = $options;

    return $this->valueOptions;
  }

}
