<?php

namespace Drupal\gbif2\Controller;

use Drupal\Component\Utility\Html;
use Drupal\Core\Controller\ControllerBase;
use ResTelae\Gbif\Species;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Controller for the GBIF module, e.g. species autocomplete.
 */
class GbifController extends ControllerBase {

  /**
   * GBIF species service, provided by the PHP GBIF library.
   *
   * @var \ResTelae\Gbif\Occurrences
   */
  protected $species;

  /**
   * Constructor.
   */
  public function __construct(Species $species) {
    $this->species = $species;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('gbif.species')
    );
  }

  /**
   * Species autocomplete.
   */
  public function speciesAutocomplete(Request $request) {
    $matches = [];

    if (!($input = $request->query->get('q'))) {
      return new JsonResponse($matches);
    }

    foreach ($this->species->nameSuggest(['q' => $input]) as $suggestion) {
      $matches[] = [
        'value' => $suggestion['key'],
        'label' => Html::escape($suggestion['scientificName'] . ' (' . $suggestion['key'] . ')'),
      ];
    }

    return new JsonResponse($matches);
  }

}
