<?php

namespace Drupal\gbif2\Service;

use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Help with GBIF integration.
 */
class Helper {

  use StringTranslationTrait;

  /**
   * Returns an enumeration for all values of BasisOfRecord.
   *
   * @return array
   *   Enumeration.
   */
  public function basisOfRecordValues() {
    return [
      'FOSSIL_SPECIMEN' => [
        'name' => $this->t('Fossil specimen'),
        'description' => $this->t('An occurrence record describing a fossilized specimen.'),
      ],
      'HUMAN_OBSERVATION' => [
        'name' => $this->t('Human observation'),
        'description' => $this->t('An occurrence record describing an observation made by one or more people.'),
      ],
      'LITERATURE' => [
        'name' => $this->t('Literature'),
        'description' => $this->t('An occurrence record based on literature alone.'),
      ],
      'LIVING_SPECIMEN' => [
        'name' => $this->t('Living specimen'),
        'description' => $this->t('An occurrence record describing a living specimen, e.g. managed animals in a zoo or cultivated plants in a garden.'),
      ],
      'MACHINE_OBSERVATION' => [
        'name' => $this->t('Machine observation'),
        'description' => $this->t('An occurrence record describing an observation made by a machine.'),
      ],
      'MATERIAL_SAMPLE' => [
        'name' => $this->t('Material sample'),
        'description' => $this->t('An occurrence record based on samples taken from other specimens or the environment.'),
      ],
      'OBSERVATION' => [
        'name' => $this->t('Observation'),
        'description' => $this->t('An occurrence record describing an observation.'),
      ],
      'PRESERVED_SPECIMEN' => [
        'name' => $this->t('Preserved specimen'),
        'description' => $this->t('An occurrence record describing a preserved specimen.'),
      ],
      'UNKNOWN' => [
        'name' => $this->t('Unknown'),
        'description' => $this->t('Unknown basis for the record.'),
      ],
    ];
  }

  /**
   * Returns an enumeration for all values of Continent.
   *
   * @return array
   *   Enumeration.
   */
  public function continentValues() {
    return [
      'AFRICA' => $this->t('Africa'),
      'ANTARTICA' => $this->t('Antartica'),
      'ASIA' => $this->t('Asia'),
      'EUROPE' => $this->t('Europe'),
      'NORTH_AMERICA' => $this->t('North America  (including the Caribbean and Central America)'),
      'OCEANIA' => $this->t('Oceania'),
      'SOUTH_AMERICA' => $this->t('South America'),
    ];
  }

}
